==> CloudClientStandardAWS_v2.0.1.zip: com/clustercontrol/ws/cloud/ModifyAccountBillingDetailRequest.java <==

package com.clustercontrol.ws.cloud;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>modifyAccountBillingDetailRequest complex typeJavaNXB
 * 
 * <p>̃XL[}EtOǵÃNXɊ܂܂\Recw肵܂B
 * 
 * <pre>
 * &lt;complexType name="modifyAccountBillingDetailRequest">
 *   &lt;complexContent>
 *     &lt;extension base="{http://cloud.ws.clustercontrol.com}cloudRequest">
 *       &lt;sequence>
 *         &lt;element name="accountResourceId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="billingDetailCollectorFlg" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/>
 *         &lt;element name="retentionPeriod" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "modifyAccountBillingDetailRequest", propOrder = {
    "accountResourceId",
    "billingDetailCollectorFlg",
    "retentionPeriod"
})
public class ModifyAccountBillingDetailRequest
    extends CloudRequest
{

    protected String accountResourceId;
    protected Boolean billingDetailCollectorFlg;
    protected Integer retentionPeriod;

    /**
     * accountResourceIdvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAccountResourceId() {
        return accountResourceId;
    }

    /**
     * accountResourceIdvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAccountResourceId(String value) {
        this.accountResourceId = value;
    }

    /**
     * billingDetailCollectorFlgvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isBillingDetailCollectorFlg() {
        return billingDetailCollectorFlg;
    }

    /**
     * billingDetailCollectorFlgvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setBillingDetailCollectorFlg(Boolean value) {
        this.billingDetailCollectorFlg = value;
    }

    /**
     * retentionPeriodvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getRetentionPeriod() {
        return retentionPeriod;
    }

    /**
     * retentionPeriodvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setRetentionPeriod(Integer value) {
        this.retentionPeriod = value;
    }

}

==> CloudClientStandardAWS_v2.0.3.zip: com/clustercontrol/ws/cloud/ModifyAccountBillingDetailRequest.java <==

package com.clustercontrol.ws.cloud;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>modifyAccountBillingDetailRequest complex typeのJavaクラス。
 * 
 * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
 * 
 * <pre>
 * &lt;complexType name="modifyAccountBillingDetailRequest">
 *   &lt;complexContent>
 *     &lt;extension base="{http://cloud.ws.clustercontrol.com}cloudRequest">
 *       &lt;sequence>
 *         &lt;element name="accountResourceId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="billingDetailCollectorFlg" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/>
 *         &lt;element name="retentionPeriod" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "modifyAccountBillingDetailRequest", propOrder = {
    "accountResourceId",
    "billingDetailCollectorFlg",
    "retentionPeriod"
})
public class ModifyAccountBillingDetailRequest
    extends CloudRequest
{

    protected String accountResourceId;
    protected Boolean billingDetailCollectorFlg;
    protected Integer retentionPeriod;

    /**
     * accountResourceIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAccountResourceId() {
        return accountResourceId;
    }

    /**
     * accountResourceIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAccountResourceId(String value) {
        this.accountResourceId = value;
    }

    /**
     * billingDetailCollectorFlgプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isBillingDetailCollectorFlg() {
        return billingDetailCollectorFlg;
    }

    /**
     * billingDetailCollectorFlgプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setBillingDetailCollectorFlg(Boolean value) {
        this.billingDetailCollectorFlg = value;
    }

    /**
     * retentionPeriodプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getRetentionPeriod() {
        return retentionPeriod;
    }

    /**
     * retentionPeriodプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setRetentionPeriod(Integer value) {
        this.retentionPeriod = value;
    }

}
